"""muninndb — alias for muninn-python, the Python SDK for MuninnDB."""

__version__ = "0.3.0-alpha"
__description__ = "Python SDK for MuninnDB — the cognitive memory database (alias for muninn-python)"
